@@ -216,7 +216,7 @@ static const uint8_t GID_START_SEQ[] = {
    creation_time is a value of PR_CREATION_TIME
 */
 void
-e_mapi_cal_util_generate_globalobjectid (gboolean is_clean, const gchar *uid, const struct timeval *exception_replace_time, const struct FILETIME *creation_time, struct Binary_r *sb)
+e_mapi_cal_util_generate_globalobjectid (gboolean is_clean, const gchar *uid, const struct timeval *exception_replace_time, const struct FILETIME *creation_time, struct SBinary_short *sb)
 {
 	GByteArray *ba;
 	guint32 val32;
@@ -1922,11 +1922,19 @@ e_mapi_cal_utils_comp_to_object (EMapiConnection *conn,
 		set_value (PidLidAppointmentSequence, &flag32);
 
 		if (cbdata->cleanglobalid) {
-			set_value (PidLidCleanGlobalObjectId, cbdata->cleanglobalid);
+			struct Binary_r bin;
+			bin.cb = cbdata->cleanglobalid->cb;
+			bin.lpb = cbdata->cleanglobalid->lpb;
+
+			set_value (PidLidCleanGlobalObjectId, &bin);
 		}
 
 		if (cbdata->globalid) {
-			set_value (PidLidGlobalObjectId, cbdata->globalid);
+			struct Binary_r bin;
+			bin.cb = cbdata->globalid->cb;
+			bin.lpb = cbdata->globalid->lpb;
+
+			set_value (PidLidGlobalObjectId, &bin);
 		}
 
 		flag32 = cbdata->resp;
@@ -1989,6 +1997,9 @@ e_mapi_cal_utils_comp_to_object (EMapiConnection *conn,
 			b = 1;
 			set_value (PidLidFInvited, &b);
 
+			tt = icaltime_as_timet (icaltime_current_time_with_zone (utc_zone));
+			set_timet_value (PidLidAttendeeCriticalChange, tt);
+
 			break;
 		case MEETING_REQUEST_RCVD :
 			set_value (PidTagMessageClass, IPM_APPOINTMENT);
@@ -2047,21 +2058,27 @@ e_mapi_cal_utils_comp_to_object (EMapiConnection *conn,
 				/* Translators: This is a meeting response prefix which will be shown in a message Subject */
 				prefix_subject (C_("MeetingResp", "Accepted:"));
 				text = IPM_SCHEDULE_MEETING_RESP_POS;
+				flag32 = 1 << 5; /* ciRespondedAccept */
 			} else if (cbdata->resp == olResponseTentative) {
 				/* Translators: This is a meeting response prefix which will be shown in a message Subject */
 				prefix_subject (C_("MeetingResp", "Tentative:"));
 				text = IPM_SCHEDULE_MEETING_RESP_TENT;
+				flag32 = 1 << 4; /* ciRespondedTentative */
 			} else if (cbdata->resp == olResponseDeclined) {
 				/* Translators: This is a meeting response prefix which will be shown in a message Subject */
 				prefix_subject (C_("MeetingResp", "Declined:"));
 				text = IPM_SCHEDULE_MEETING_RESP_NEG;
+				flag32 = 1 << 6; /* ciRespondedDecline */
 			} else {
 				text = "";
+				flag32 = 1 << 11; /* ciCanceled */
 			}
 			#undef prefix_subject
 			set_value (PidTagMessageClass, text);
 			text = NULL;
 
+			set_value (PidLidClientIntent, &flag32);
+
 			flag32 = 0xFFFFFFFF;  /* no idea why this has to be -1, but that's what the docs say */
 			set_value (PidTagIconIndex, &flag32);
 
@@ -2074,6 +2091,9 @@ e_mapi_cal_utils_comp_to_object (EMapiConnection *conn,
 			flag32 = mtgEmpty;
 			set_value (PidLidMeetingType, &flag32);
 
+			tt = icaltime_as_timet (icaltime_current_time_with_zone (utc_zone));
+			set_timet_value (PidLidAppointmentReplyTime, tt);
+
 			break;
 		case NOT_A_MEETING :
 		default :
